@@ -2,7 +2,7 @@ from pathlib import Path
 import os
 
 
-default_data_dir = Path(os.path.expanduser('~/pynando/'))
+default_data_dir = Path(os.path.expanduser('~/pynando_data/'))
 resources = ['shoman', 'nanbyo', 'shoman_class', 'nanbyo_class']
 
 
